@@ -23,6 +23,7 @@ type PolicySpecSyncOptions struct {
 	HubConfigFilePathName     string
 	ManagedConfigFilePathName string
 	EnableLease               bool
+	ProbeAddr                 string
 }
 
 // Options default value
@@ -66,6 +67,13 @@ func ProcessFlags() {
 		false,
 		"If enabled, the controller will start the lease controller to report its status",
 	)
+
+	flag.StringVar(
+		&Options.ProbeAddr,
+		"health-probe-bind-address",
+		":8082",
+		"The address the probe endpoint binds to.",
+	)
 }
 
 // CreateClusterNs creates the cluster namespace on managed cluster if not exists
